@@ -8,11 +8,11 @@ class Recipe:
         self.name = name
         self.options = options
         options.setdefault('eggs', '')
-
+    
     def install(self):
         log = logging.getLogger(self.name)
-        eggs = self.options['eggs']
-        eggs = eggs.split('\n')
+        eggs = self.options['eggs'].strip()
+        eggs = [s.strip() for s in eggs.split('\n')]
         
         dev_egg_dir = self.buildout['buildout']['develop-eggs-directory']
         
@@ -27,6 +27,8 @@ class Recipe:
                 log.info('Using %s for %s' % (dist.location, egg))
             except pkg_resources.DistributionNotFound:
                 log.warn('No system distribution for %s found.' % egg)
+                if 'force-sysegg' in self.options:
+                    raise
         return ()
 
     update = install
\ No newline at end of file
